==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/fr/settings.php <==
<?php
return array (
  '1 month' => '1 mois',
  '1 week' => '1 semaine',
  '1 year' => '1 an',
  '2 weeks' => '2 semaines',
  '3 months' => '3 mois',
  '6 months' => '6 mois',
  '<strong>Confirm</strong> icon deletion' => '<strong>Confirmer</strong> la suppression de l\'icône',
  '<strong>Confirm</strong> image deletion' => '<strong>Confirmer</strong> la suppression de l\'image',
  '<strong>Maintenance</strong> Mode' => 'Mode <strong>maintenance</strong>',
  '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Attention:</strong> Tous les utilisateurs seront déconnectés, à l\'exception des administrateurs.',
  'APC(u)' => 'APC(u)',
  'Activate' => 'Activer',
  'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Activer le mode maintenance et refuser l\'accès au site pour les utilisateurs qui ne sont pas administrateur ?<br><br>',
  'Add OEmbed provider' => 'Ajouter un fournisseur OEmbed',
  'Add custom info text for maintenance mode. Displayed on the login page.' => 'Ajouter un texte personnaliser pour le mode maintenance. Il sera afficher sur la page de connexion.',
  'Add new provider' => 'Ajouter un nouveau fournisseur',
  'Advanced Settings' => 'Paramètres avancés',
  'Allow Self-Signed Certificates?' => 'Autoriser les certificats auto-signés ?',
  'Allowed file extensions' => 'Extensions autorisées',
  'Alphabetical' => 'Alphabétique',
  'Appearance Settings' => 'Paramètres d\'apparence',
  'Auto format based on user language - Example: {example}' => 'Format automatique basé sur la langue de l\'utilisateur - Exemple : {example}',
  'Back to overview' => 'Retour à l\'aperçu',
  'Base URL' => 'URL de base',
  'Cache Backend' => 'Type de mémoire cache',
  'Comma separated list. Leave empty to allow all.' => 'Liste séparée par des virgules (laisser vide pour tout autoriser)',
  'Could not send test email.' => 'L\'envoi du courrier de test a échoué.',
  'Currently no provider active!' => 'Aucun fournisseur actif actuellement.',
  'Currently there are {count} records in the database dating from {dating}.' => 'Il y a actuellement {count} enregistrements dans la base de données datant de {dating}.',
  'Dashboard' => 'Fil d\'actualités',
  'Date input format' => 'Format de saisie de date',
  'Deactivate' => 'Désactiver',
  'Deactivate maintenance mode and enable all users to access the platform again?' => 'Désactiver le mode maintenance et autoriser les utilisateurs à se connecter de nouveau au site ?',
  'Default Expire Time (in seconds)' => 'Temps d\'expiration par défaut (en secondes)',
  'Default Timezone' => 'Fuseau horaire par défaut',
  'Default language' => 'Langue par défaut',
  'Default pagination size (Entries per page)' => 'Taille de pagination par défaut (entrées par page)',
  'Default stream content order' => 'Ordre du contenu par défaut dans le fil d\'actualités',
  'Delete' => 'Supprimer',
  'Display Name (Format)' => 'Nom affiché (format)',
  'Dropdown space order' => 'Ordre des espaces dans la liste déroulante',
  'E-Mail' => 'E-mail',
  'E-Mail sender address' => 'Adresse expéditeur des e-mails',
  'E-Mail sender name' => 'Nom de l\'expéditeur des e-mails',
  'E.g. http://example.com/humhub' => 'p.ex. https://exemple.com/humhub',
  'Edit OEmbed provider' => 'Modifier le fournisseur OEmbed',
  'Enable maintenance mode' => 'Activer le mode maintenance',
  'Enable user friendship system' => 'Activer le système d\'amitié',
  'Enabled' => 'Activé',
  'Enabled OEmbed providers' => 'Activer les fournisseurs OEmbed',
  'Encryption' => 'Chiffrement',
  'Endpoint Url' => 'URL de point de terminaison',
  'Exclude media files from stream attachment list' => 'Exclure les fichiers multimédia de la liste des fichiers attachés',
  'File' => 'Fichier',
  'Firstname Lastname (e.g. John Doe)' => 'Prénom Nom (p.ex. Pierre Dupont)',
  'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Format fixe (jj/mm/aaaa) (p.ex. {example})',
  'Friendship' => 'Amitié',
  'General' => 'Général',
  'General Settings' => 'Paramètres généraux',
  'HTML tracking code' => 'Code HTML de suivi de statistiques',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Ici, vous pouvez configurer le comportement d\'enregistrement et les paramètres utilisateur supplémentaires de votre réseau social.',
  'Here you can configure basic settings of your social network.' => 'Vous pouvez configurer ici les paramètres basiques de votre réseau social.',
  'Horizontal scrolling images on a mobile device' => 'Défilement horizontal des images pour les mobiles',
  'Icon upload' => 'Charger une icône',
  'Last visit' => 'Dernière visite',
  'Logo upload' => 'Charger un logo',
  'Mail Transport Type' => 'Type de transport des e-mails',
  'Maintenance mode' => 'Mode maintenance',
  'Maximum allowed age for logs.' => 'Durée maximale de maintien des logs.',
  'Maximum upload file size (in MB)' => 'Taille maximale autorisée pour le transfert de fichiers (en Mo)',
  'Mobile appearance' => 'Affichage mobile',
  'Name of the application' => 'Nom de l\'application',
  'No Proxy Hosts' => 'Pas d\'hôtes de proxy',
  'No caching' => 'Cache désactivé',
  'Notification Settings' => 'Paramètres des notifications',
  'Old logs can significantly increase the size of your database while providing little information.' => 'Les anciens journaux peuvent considérablement augmenter la taille de votre base de données tout en fournissant peu d\'information pertinente.',
  'PHP APC(u) Extension missing - Type not available!' => 'L\'extension PHP APC(u) n\'est pas installée.',
  'PHP reported a maximum of {maxUploadSize} MB' => 'Valeur maximale configurée actuellement dans PHP {maxUploadSize}Mo',
  'Password' => 'Mot de passe',
  'Port' => 'Port',
  'Port number' => 'Port (p.ex. 25)',
  'Prevent client caching of following scripts' => 'Empêcher la mise en cache client des scripts suivants',
  'Redis' => 'Redis',
  'Reported database time: {dateTime}' => 'Temps de base de données rapporté: {dateTime}',
  'SMTP Options' => 'Options SMTP',
  'Save' => 'Enregistrer',
  'Save & Flush Caches' => 'Enregistrer et purger le cache',
  'Save & Test' => 'Enregistrer et Tester',
  'Saved' => 'Enregistré',
  'Saved and flushed cache' => 'Enregistré et cache purgé',
  'Saved and sent test email to: {address}' => 'Enregistré et e-mail test envoyé à {address}',
  'Server' => 'Serveur',
  'Server Timezone' => 'Fuseau horaire du serveur',
  'Show introduction tour for new users' => 'Afficher les "premiers pas" pour les nouveaux utilisateurs',
  'Show user profile post form on dashboard' => 'Afficher le contenu du profil utilisateur sur le fil d\'actualités',
  'Sort by creation date' => 'par date de création',
  'Sort by update date' => 'par date de mise à jour',
  'Test message' => 'Message de test',
  'Theme' => 'Thème',
  'These settings refer to advanced topics of your social network.' => 'Ces paramètres concernent les sujets avancés de votre réseau social.',
  'These settings refer to the appearance of your social network.' => 'Ces paramètres concernent l\'apparence de votre réseau social.',
  'Url Prefix' => 'Préfixe de l\'URL',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'URL sans http:// ou https:// (p.ex. youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Utiliser %url% comme espace réservé pour l\'URL. Le format doit être JSON. (p.ex. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
  'Use X-Sendfile for File Downloads' => 'Utiliser X-Sendfile pour le téléchargement des fichiers',
  'Use the default swipe to show sidebar on a mobile device' => 'Utiliser le geste glisser pour afficher le menu latéral droit sur les tablettes/portables',
  'User' => 'Identifiant',
  'User Settings' => 'Paramètres utilisateurs',
  'Username' => 'Identifiant',
  'Username (e.g. john)' => 'Identifiant (p.ex. pierre)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Vous pouvez ajouter un extrait de code HTML de statistiques - qui sera ajouté à toutes les pages rendues.',
  'You\'re using no icon at the moment. Upload your logo now.' => 'Vous n\'utilisez pas d\'icône pour le moment. Chargez votre logo maintenant.',
  'You\'re using no logo at the moment. Upload your logo now.' => 'Vous n\'utilisez pas de logo pour le moment. Chargez votre logo maintenant.',
  'never' => 'jamais',
);

==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/admin/messages/fr/settings.php <==
<?php
return array (
  '1 month' => '1 mois',
  '1 week' => '1 semaine',
  '1 year' => '1 an',
  '2 weeks' => '2 semaines',
  '3 months' => '3 mois',
  '6 months' => '6 mois',
  '<strong>Confirm</strong> icon deletion' => '<strong>Confirmer</strong> la suppression de l\'icône',
  '<strong>Confirm</strong> image deletion' => '<strong>Confirmer</strong> la suppression de l\'image',
  '<strong>Maintenance</strong> Mode' => 'Mode <strong>maintenance</strong>',
  '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Attention:</strong> Tous les utilisateurs seront déconnectés, à l\'exception des administrateurs.',
  'APC(u)' => 'APC(u)',
  'Access Token' => 'Jeton d’accès',
  'Access token is not provided yet.' => 'Le jeton d’accès n’est pas encore fourni.',
  'Activate' => 'Activer',
  'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Activer le mode maintenance et refuser l\'accès au site pour les utilisateurs qui ne sont pas administrateur ?<br><br>',
  'Add OEmbed provider' => 'Ajouter un fournisseur OEmbed',
  'Add custom info text for maintenance mode. Displayed on the login page.' => 'Ajouter un texte personnaliser pour le mode maintenance. Il sera afficher sur la page de connexion.',
  'Add new provider' => 'Ajouter un nouveau fournisseur',
  'Advanced Settings' => 'Paramètres avancés',
  'Allow Self-Signed Certificates?' => 'Autoriser les certificats auto-signés ?',
  'Allowed file extensions' => 'Extensions autorisées',
  'Alphabetical' => 'Alphabétique',
  'Appearance Settings' => 'Paramètres d\'apparence',
  'Auto format based on user language - Example: {example}' => 'Format automatique basé sur la langue de l\'utilisateur - Exemple : {example}',
  'Back to overview' => 'Retour à l\'aperçu',
  'Base URL' => 'URL de base',
  'Cache Backend' => 'Type de mémoire cache',
  'Comma separated list. Leave empty to allow all.' => 'Liste séparée par des virgules (laisser vide pour tout autoriser)',
  'Configuration (Use settings from configuration file)' => 'Configuration (utiliser les réglages du fichier de configuration)',
  'Could not send test email.' => 'L\'envoi du courrier de test a échoué.',
  'Currently no provider active!' => 'Aucun fournisseur actif actuellement.',
  'Currently there are {count} records in the database dating from {dating}.' => 'Il y a actuellement {count} enregistrements dans la base de données datant de {dating}.',
  'Custom DSN' => '',
  'DSN' => '',
  'DSN Examples:' => '',
  'Dashboard' => 'Fil d\'actualités',
  'Date input format' => 'Format de saisie de date',
  'Deactivate' => 'Désactiver',
  'Deactivate maintenance mode and enable all users to access the platform again?' => 'Désactiver le mode maintenance et autoriser les utilisateurs à se connecter de nouveau au site ?',
  'Default Expire Time (in seconds)' => 'Temps d\'expiration par défaut (en secondes)',
  'Default Timezone' => 'Fuseau horaire par défaut',
  'Default language' => 'Langue par défaut',
  'Default pagination size (Entries per page)' => 'Taille de pagination par défaut (entrées par page)',
  'Default stream content order' => 'Ordre du contenu par défaut dans le fil d\'actualités',
  'Delete' => 'Supprimer',
  'Dropdown space order' => 'Ordre des espaces dans la liste déroulante',
  'E-Mail' => 'E-mail',
  'E-Mail reply-to' => 'E-mail de réponse (reply-to)',
  'E-Mail sender address' => 'Adresse expéditeur des e-mails',
  'E-Mail sender name' => 'Nom de l\'expéditeur des e-mails',
  'E.g. http://example.com/humhub' => 'p.ex. https://exemple.com/humhub',
  'Edit OEmbed provider' => 'Modifier le fournisseur OEmbed',
  'Embedded content requires the user\'s consent to be loaded' => 'Le contenu intégré nécessite de charger le consentement de l’utilisateur ou de l’utilisatrice',
  'Enable maintenance mode' => 'Activer le mode maintenance',
  'Enable user friendship system' => 'Activer le système d\'amitié',
  'Enabled' => 'Activé',
  'Enabled OEmbed providers' => 'Activer les fournisseurs OEmbed',
  'Endpoint Url' => 'URL de point de terminaison',
  'Exclude media files from stream attachment list' => 'Exclure les fichiers multimédia de la liste des fichiers attachés',
  'File' => 'Fichier',
  'Firstname Lastname (e.g. John Doe)' => 'Prénom Nom (p.ex. Pierre Dupont)',
  'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Format fixe (jj/mm/aaaa) (p.ex. {example})',
  'Friendship' => 'Amitié',
  'General' => 'Général',
  'General Settings' => 'Paramètres généraux',
  'HTML tracking code' => 'Code HTML de suivi de statistiques',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Ici, vous pouvez configurer le comportement d\'enregistrement et les paramètres utilisateur supplémentaires de votre réseau social.',
  'Here you can configure basic settings of your social network.' => 'Vous pouvez configurer ici les paramètres basiques de votre réseau social.',
  'Horizontal scrolling images on a mobile device' => 'Défilement horizontal des images pour les mobiles',
  'Icon upload' => 'Charger une icône',
  'Last visit' => 'Dernière visite',
  'Logo upload' => 'Charger un logo',
  'Mail Transport Type' => 'Type de transport des e-mails',
  'Maintenance mode' => 'Mode maintenance',
  'Maximum allowed age for logs.' => 'Durée maximale de maintien des logs.',
  'Maximum upload file size (in MB)' => 'Taille maximale autorisée pour le transfert de fichiers (en Mo)',
  'Mobile appearance' => 'Affichage mobile',
  'Name of the application' => 'Nom de l\'application',
  'No Delivery (Debug Mode, Save as file)' => 'Pas de distribution (mode de déboguage, enregistrement dans un fichier)',
  'No Proxy Hosts' => 'Pas d\'hôtes de proxy',
  'No caching' => 'Cache désactivé',
  'Notification Settings' => 'Paramètres des notifications',
  'Old logs can significantly increase the size of your database while providing little information.' => 'Les anciens journaux peuvent considérablement augmenter la taille de votre base de données tout en fournissant peu d\'information pertinente.',
  'Optional. Default reply address for system emails like notifications.' => 'Optionnel. Adresse de réponse par défaut pour les e-mails système tels que les notifications.',
  'PHP (Use settings of php.ini file)' => 'PHP (utilise les réglages du fichier php.ini)',
  'PHP APC(u) Extension missing - Type not available!' => 'L\'extension PHP APC(u) n\'est pas installée.',
  'PHP reported a maximum of {maxUploadSize} MB' => 'Valeur maximale configurée actuellement dans PHP {maxUploadSize}Mo',
  'Password' => 'Mot de passe',
  'Port' => 'Port',
  'Port number' => 'Port (p.ex. 25)',
  'Prevent client caching of following scripts' => 'Empêcher la mise en cache client des scripts suivants',
  'Provider Name' => 'Nom du fournisseur',
  'Redis' => 'Redis',
  'Regular expression by which the link match will be checked.' => 'Expression régulière utilisée pour vérifier la validité du lien.',
  'Reported database time: {dateTime}' => 'Temps de base de données rapporté: {dateTime}',
  'Save' => 'Enregistrer',
  'Save & Flush Caches' => 'Enregistrer et purger le cache',
  'Save & Test' => 'Enregistrer et Tester',
  'Saved' => 'Enregistré',
  'Saved and flushed cache' => 'Enregistré et cache purgé',
  'Saved and sent test email to: {address}' => 'Enregistré et e-mail test envoyé à {address}',
  'Server' => 'Serveur',
  'Server Timezone' => 'Fuseau horaire du serveur',
  'Show introduction tour for new users' => 'Afficher les "premiers pas" pour les nouveaux utilisateurs',
  'Show user profile post form on dashboard' => 'Afficher le formulaire de publication du profil utilisateur sur le fil d\'actualités global',
  'Sort by creation date' => 'par date de création',
  'Sort by update date' => 'par date de mise à jour',
  'Test message' => 'Message de test',
  'Theme' => 'Thème',
  'These settings refer to advanced topics of your social network.' => 'Ces paramètres concernent les sujets avancés de votre réseau social.',
  'These settings refer to the appearance of your social network.' => 'Ces paramètres concernent l\'apparence de votre réseau social.',
  'Url Pattern' => 'Motif d’URL',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Utiliser %url% comme espace réservé pour l\'URL. Le format doit être JSON. (p.ex. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
  'Use SMTPS' => 'Utiliser SMTPS',
  'Use X-Sendfile for File Downloads' => 'Utiliser X-Sendfile pour le téléchargement des fichiers',
  'Use the default swipe to show sidebar on a mobile device' => 'Utiliser le geste glisser pour afficher le menu latéral droit sur les tablettes/portables',
  'User' => 'Identifiant',
  'User Display Name' => '',
  'User Display Name Subtitle' => '',
  'User Settings' => 'Paramètres utilisateurs',
  'Username' => 'Identifiant',
  'Username (e.g. john)' => 'Identifiant (p.ex. pierre)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Vous pouvez ajouter un extrait de code HTML de statistiques - qui sera ajouté à toutes les pages rendues.',
  'You can find more configuration options here:' => 'Vous trouverez plus d’options de configuration là :',
  'You\'re using no icon at the moment. Upload your logo now.' => 'Vous n\'utilisez pas d\'icône pour le moment. Chargez votre logo maintenant.',
  'You\'re using no logo at the moment. Upload your logo now.' => 'Vous n\'utilisez pas de logo pour le moment. Chargez votre logo maintenant.',
  'e.g. 25 (for SMTP) or 587 (for SMTPS)' => 'par exemple 25 (pour SMTP) ou 587 (pour SMTPS)',
  'e.g. localhost' => 'par exemple « localhost »',
  'e.g. smtps://user:pass@smtp.example.com:port' => 'par exemple : smtps://identifiant:motdepasse@smtp.exemple.com:port',
  'never' => 'jamais',
);
